@@ -1,3 +1,3 @@
 EMAIL = 'jorge.cardoso.pt@gmail.com'
 USER_ID = '79cc4a8a-c1ff-4852-9486-62fd8e618623'
-PASSWORD = 'sawhUz-hanpe4-zaqtyr'
+PASSWORD = 'ginrom-xUrfib-2sumfa'
